;; publish.el --- Publish org-mode project on Gitlab Pages
;; Author: Rasmus
(package-initialize)

(require 'org)
(require 'ox-publish)
(require 'ox-extra)
(ox-extras-activate '(latex-header-blocks ignore-headlines))

(setq org-publish-use-timestamps-flag nil)

(setq user-full-name "Samuel W. Flint")
(setq user-mail-address "swflint@flintfam.org")

(setq org-todo-keywords '((sequence "TODO(t)" "WORKING(w)" "|" "DONE(d)")
                          (sequence "REPORT(r)" "BUG(b)" "KNOWNCAUSE(k)" "|" "FIXED(f)")
                          (sequence "|" "CANCELLED(c)")))

(setq org-export-with-smart-quotes t
      org-export-with-toc t
      org-export-with-todo-keywords t)

(setf org-latex-image-default-width ""
      org-latex-table-scientific-notation "%s\\times10^{%s}"
      org-latex-prefer-user-labels t
      org-export-latex-hyperref-format "\\hyperref{%s}"
      org-latex-listings t
      org-latex-packages-alist '(("" "lmodern" nil)
                                 ("" "natbib" nil)
                                 ("" "csquotes" nil)
                                 ("" "color" nil)
                                 ("" "listings" nil)
                                 ("" "color" nil)
                                 ("UTF8" "inputenc" nil))
      org-latex-classes '(("article" "\\documentclass[10pt,twoside,letterpaper]{article}"
                           ("\\section{%s}" . "\\section*{%s}")
                           ("\\subsection{%s}" . "\\subsection*{%s}")
                           ("\\subsubsection{%s}" . "\\subsubsection*{%s}")
                           ("\\paragraph{%s}" . "\\paragraph*{%s}")
                           ("\\subparagraph{%s}" . "\\subparagraph*{%s}"))
                          ("report" "\\documentclass[11pt]{report}"
                           ("\\chapter{%s}" . "\\chapter*{%s}")
                           ("\\section{%s}" . "\\section*{%s}")
                           ("\\subsection{%s}" . "\\subsection*{%s}")
                           ("\\subsubsection{%s}" . "\\subsubsection*{%s}")
                           ("\\paragraph{%s}" . "\\paragraph*{%s}"))
                          ("book" "\\documentclass[11pt]{book}"
                           ("\\part{%s}" . "\\part*{%s}")
                           ("\\chapter{%s}" . "\\chapter*{%s}")
                           ("\\section{%s}" . "\\section*{%s}")
                           ("\\subsection{%s}" . "\\subsection*{%s}")
                           ("\\subsubsection{%s}" . "\\subsubsection*{%s}"))
                          ("beamer" "\\documentclass{beamer}" org-beamer-sectioning))
      org-latex-pdf-process '("pdflatex -shell-escape -interaction nonstopmode -output-directory %o %f"
                              "bibtex %b"
                              "pdflatex -shell-escape -interaction nonstopmode -output-directory %o %f"
                              "pdflatex -shell-escape -interaction nonstopmode -output-directory %o %f"))

(defvar site-attachments
  (regexp-opt '("jpg" "jpeg" "gif" "png" "svg"
                "ico" "cur" "css" "js" "woff" "html" "pdf")))

(setq org-publish-project-alist
      (list
       (list "site-org"
             :base-directory "."
             :base-extension "org"
             :recursive t
             :publishing-function '(org-latex-publish-to-pdf)
             :publishing-directory "./public"
             :exclude (regexp-opt '("README" "draft")))
       (list "site" :components '("site-org"))))

(setf org-confirm-babel-evaluate
      (lambda (lang body)
        (declare (ignorable lang body))
        nil))
